@@ -78,9 +78,10 @@ class Wsdl(WsdlBase):
                                     'cl_update_check_rep_set',
                                     'cl_update_force_fix_set',
                                     'cl_update_world',
+                                    'cl_update_gpg_force',
                                     'cl_update_egencache_force',
                                     'cl_update_eixupdate_force',
-                                    'cl_update_skip_rb_set',
+                                    'cl_update_revdep_rebuild_set',
                                     'cl_update_wait_another_set',
                                     'cl_update_autocheck_schedule_set',
                                     'cl_update_onedepth_set',
